H2n: Compute Normalisation Factor

View source: R/tapered_estimator.R

H2nR Documentation

Compute Normalisation Factor

Description

This helper function is used in the computation of the normalisation factor the function tapered_est,

H_{2, n}(0) = \sum_{s=1}^{n} a((s - 1/2) / n; \rho)^{2},

where a(\cdot; \cdot) is a window function.

Usage

H2n(
  n,
  rho,
  window_name = c("tukey", "triangular", "sine", "power_sine", "blackman",
    "hann_poisson", "welch"),
  window_params = c(1),
  custom_window = FALSE
)

Arguments

n

The sample size.

rho

A scale parameter in (0, 1].

window_name

The name of the window_ec function to be used. Possible values are: tukey, triangular, power_sine, blackman_window, hann_poisson, welch. Alternatively, a custom window function can be provided, see the example for taper.

window_params

A vector of parameters of the window function.

custom_window

If a custom window is to be used or not. Defaults to FALSE.

Value

A single value being H_{2, n}(0).

Examples

## Not run: 
H2n(3, 0.6, "tukey")

## End(Not run)

CovEsts documentation built on April 19, 2026, 5:06 p.m.

Related to H2n in CovEsts...