Xij_mat: Compute X_{ij} Matrix

View source: R/kernel_regression_estimator.R

Xij_matR Documentation

Compute X_{ij} Matrix

Description

This helper function computes the matrix of pairwise values, X_{ij}, for the kernel regression estimator,

X_{ij} = (X_{i} - \bar{X}) (X_{j} - \bar{X}) .

Usage

Xij_mat(X, meanX = mean(X))

Arguments

X

A vector of values.

meanX

The average value of X. Defaults to mean(X).

Value

A matrix of size N \times N, where N is the length of the vector X.

References

Hall, P. & Patil, P. (1994). Properties of nonparametric estimators of autocovariance for stationary random fields. Probability Theory and Related Fields 99(3), 399-424. https://doi.org/10.1007/bf01199899

Hall, P., Fisher, N. I., & Hoffmann, B. (1994). On the nonparametric estimation of covariance functions. The Annals of Statistics 22(4), 2115-2134. https://doi.org/10.1214/aos/1176325774

Examples

## Not run: 
X <- c(1, 2, 3, 4)
Xij_mat(X, mean(X))

## End(Not run)

CovEsts documentation built on April 19, 2026, 5:06 p.m.

Related to Xij_mat in CovEsts...