adjusted_spline: Compute Adjusted Splines.

View source: R/B_splines_est.R

adjusted_splineR Documentation

Compute Adjusted Splines.

Description

A helper function that is an implementation of the formula from Choi, Li & Wang (2013, p. 616),

f_{j}^{(l)}(x) = \frac{m + 1}{l} \left( f_{j}^{(l - 1)}(x + 1) - \tau_{j - p} f_{j}^{(l - 1)}(x) + \tau_{j - p + l + 1} f_{j + 1}^{(l - 1)}(x) - f_{j + 1}^{(l - 1)}(x + 1) \right) ,

where m is the number of nonboundary knots, p is the order of the spline, l is the order of the adjusted spline (the function f_{j}^{(l)}(\cdot)) and j = 1, 2, \dots , m + p.

Usage

adjusted_spline(x, j, l, p, m, taus)

Arguments

x

Argument of the function.

j

Index of basis function of order l.

l

Order of function.

p

The order of the splines.

m

The number of nonboundary knots.

taus

Vector of \taus, see get_taus.

Value

A numeric value of the adjusted spline f_{j}^{(l)}(x).

References

Choi, I., Li, B. & Wang, X. (2013). Nonparametric Estimation of Spatial and Space-Time Covariance Function. JABES 18, 611-630. https://doi.org/10.1007/s13253-013-0152-z

Examples

## Not run: 
taus <- get_taus(3, 2)
adjusted_spline(1, 2, 1, 3, 2, taus)

## End(Not run)

CovEsts documentation built on April 19, 2026, 5:06 p.m.