mse: MSE Between Estimated Autocovariance Functions.

View source: R/metrics.R

mseR Documentation

MSE Between Estimated Autocovariance Functions.

Description

This function computes the mean-square difference/error between two autocovariance functions (estimated or theoretical).

Usage

mse(est1, est2)

## S3 method for class 'CovEsts'
mse(est1, est2)

## Default S3 method:
mse(est1, est2)

Arguments

est1

A numeric vector representing the first estimated autocovariance function.

est2

A numeric vector of the same length as est1 representing the second estimated (or theoretical) autocovariance function

Details

This function computes the mean-square difference/error (MSE) between two estimated autocovariance functions (estimated or theoretical). The MSE is defined as

\frac{1}{n} \sum_{i=0}^{n} \left(\widehat{C}_{1}(h_{i}) - \widehat{C}_{2}(h_{i})\right)^{2}

over a set of lags \{h_{0}, h_{1} , h_{2} , \dots , h_{n} \}.

Value

A numeric value representing the MSE between two autocovariance functions (estimated or theoretical).

Methods (by class)

  • mse(CovEsts): Method for CovEsts object.

  • mse(default): Method for numeric vectors.

Examples

x <- seq(0, 5, by=0.1)
estCov1 <- exp(-x^2)
estCov2 <- exp(-x^2.1)
mse(estCov1, estCov2)

CovEsts documentation built on April 19, 2026, 5:06 p.m.

Related to mse in CovEsts...