| normalise_acf | R Documentation |
This function normalises a CovEsts S3 object, that is, turning an autocovariance function into an autocorrelation function. This procedure is a one-way transformation. This function does not support any other type of argument.
normalise_acf(estCov)
## Default S3 method:
normalise_acf(estCov)
## S3 method for class 'CovEsts'
normalise_acf(estCov)
estCov |
A CovEst S3 object. |
A CovEsts S3 object with a normalised acf attribute.
normalise_acf(default): Method for other objects.
normalise_acf(CovEsts): Method for 'CovEsts' objects.
normalise_acf(standard_est(c(1, 2, 3)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.