print.BootEsts: Print Method for BootEsts Objects

View source: R/plotting.R

print.BootEstsR Documentation

Print Method for BootEsts Objects

Description

This function plots a BootEsts object, printing estimtor type, bootstrap type, estimator used, the bootstrap average estimate, the original estimate, and the pointwise confidence interval.

Usage

## S3 method for class 'BootEsts'
print(x, n_head = 5, n_tail = 5, digits = NULL, ...)

Arguments

x

A BootEsts S3 object.

n_head

The number of 'head' values to print, defaults to 5.

n_tail

The number of 'tail' values to print, defaults to 5.

digits

The number of digits to print. Defaults to NULL. Note, this value is passed into base::format.

...

Addition printing parameters, see base::print.

Value

Prints a BootEsts object.

Examples

print(block_bootstrap(c(1, 2, 3), 2))

CovEsts documentation built on April 19, 2026, 5:06 p.m.