spectral_norm: Compute the Spectral Norm Between Estimated Functions.

View source: R/metrics.R

spectral_normR Documentation

Compute the Spectral Norm Between Estimated Functions.

Description

This function computes the spectral norm of the difference of two estimated autocovariance functions. This function is intended for estimates over lags with a constant difference.

Usage

spectral_norm(est1, est2)

## S3 method for class 'CovEsts'
spectral_norm(est1, est2)

## Default S3 method:
spectral_norm(est1, est2)

Arguments

est1

A numeric vector representing the first estimated autocovariance function.

est2

A numeric vector of the same length as est1 representing the second estimated autocovariance function

Details

This function computes the spectral norm of the difference of two estimated autocovariance functions. Let D(h) = \hat{C}_{1}(h) - \hat{C}_{2}(h), where \hat{C}_{1}(\cdot) and \hat{C}_{2}(\cdot) are estimated autocovariance functions.

A matrix D is created from D(\cdot),

\left[ {\begin{array}{ccccc} D(h_{0}) & D(h_{1}) & \cdots & D(h_{n - 1}) & D(h_{n}) \\ D(h_{1}) & D(h_{0}) & \cdots & D(h_{n - 2}) & D(h_{n - 1}) \\ \vdots & \vdots & \ddots & \vdots & \vdots \\ D(h_{n - 1}) & D(h_{n - 2}) & \cdots & D(h_{0}) & D(h_{1}) \\ D(h_{n}) & D(h_{n - 1}) & \cdots & D(h_{1}) & D(h_{0}) \\ \end{array}} \right] ,

over a set of lags \{h_{0}, h_{1}, \dots , h_{N} \}. This matrix is created by cyclic_matrix.

The spectral norm is defined as the largest eigenvalue of D.

Value

The spectral norm of the differences between the two functions.

Methods (by class)

  • spectral_norm(CovEsts): Method for CovEsts objects.

  • spectral_norm(default): Method for numeric vectors.

Examples

x <- seq(0, 5, by=0.1)
estCov1 <- exp(-x^2)
estCov2 <- exp(-x^2.1)
spectral_norm(estCov1, estCov2)

CovEsts documentation built on April 19, 2026, 5:06 p.m.