splines_df: Construct Data Frame of Basis Functions.

View source: R/B_splines_est.R

splines_dfR Documentation

Construct Data Frame of Basis Functions.

Description

This helper function constructs a data frame with the following structure:

  • One column for the x-values

  • m + p columns values of squared basis functions evaluated at the corresponding x.

Usage

splines_df(x, p, m, taus)

Arguments

x

A vector of lags.

p

The order of the splines.

m

The number of nonboundary knots.

taus

Vector of \taus, see get_taus.

Value

A data frame of the above structure.

Examples

## Not run: 
taus <- get_taus(3, 2)
splines_df(seq(0, 2, by=0.25), 3, 2, taus)

## End(Not run)

CovEsts documentation built on April 19, 2026, 5:06 p.m.

Related to splines_df in CovEsts...