to_pacf: Computes the Standard Estimator of the Autocovariance...

View source: R/standard_est.R

to_pacfR Documentation

Computes the Standard Estimator of the Autocovariance Function.

Description

This function computes the partial autocorrelation function from an estimated autocovariance or autocorrelation function.

Usage

to_pacf(estCov)

## S3 method for class 'CovEsts'
to_pacf(estCov)

## Default S3 method:
to_pacf(estCov)

Arguments

estCov

A numeric vector representing an estimated autocovariance or autocorrelation function.

Details

This function is a translation of the 'uni_pacf' function in src/library/stats/src/pacf.c of the R source code which is an implementation of the Durbin-Levinson algorithm.

Value

A vector whose values are an estimate partial autocorrelation function or a CovEsts S3 object (list) with the following values

acf

A numeric vector containing the partial autocorrelation estimates.

lags

A numeric vector containing the lag indices used to compute the estimates on.

est_type

The type of estimate, namely 'partial'.

est_used

The estimator function used, in this case, 'to_pacf'.

If a numeric vector is given for the argument estCov, then a numeric vector output is given, and if a CovEsts S3 object is given, a CovEsts object is given as output.

Methods (by class)

  • to_pacf(CovEsts): Method for CovEsts objects.

  • to_pacf(default): Method for numeric vectors.

Examples

X <- c(1, 2, 3)
to_pacf(standard_est(X, pd = FALSE, maxLag = 2, meanX = mean(X)))

CovEsts documentation built on April 19, 2026, 5:06 p.m.

Related to to_pacf in CovEsts...