View source: R/tapered_estimator.R
| H2n | R Documentation |
This helper function is used in the computation of the normalisation factor the function tapered_est,
H_{2, n}(0) = \sum_{s=1}^{n} a((s - 1/2) / n; \rho)^{2},
where a(\cdot; \cdot) is a window function.
H2n(
n,
rho,
window_name = c("tukey", "triangular", "sine", "power_sine", "blackman",
"hann_poisson", "welch"),
window_params = c(1),
custom_window = FALSE
)
n |
The sample size. |
rho |
A scale parameter in |
window_name |
The name of the window_ec function to be used. Possible values are: tukey, triangular, power_sine, blackman_window, hann_poisson, welch. Alternatively, a custom window function can be provided, see the example for taper. |
window_params |
A vector of parameters of the window function. |
custom_window |
If a custom window is to be used or not. Defaults to |
A single value being H_{2, n}(0).
## Not run:
H2n(3, 0.6, "tukey")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.