View source: R/B_splines_est.R
| adjusted_spline | R Documentation |
A helper function that is an implementation of the formula from Choi, Li & Wang (2013, p. 616),
f_{j}^{(l)}(x) = \frac{m + 1}{l} \left( f_{j}^{(l - 1)}(x + 1) - \tau_{j - p} f_{j}^{(l - 1)}(x) + \tau_{j - p + l + 1} f_{j + 1}^{(l - 1)}(x) - f_{j + 1}^{(l - 1)}(x + 1) \right) ,
where m is the number of nonboundary knots, p is the order of the spline, l is the order of the adjusted spline (the function f_{j}^{(l)}(\cdot)) and j = 1, 2, \dots , m + p.
adjusted_spline(x, j, l, p, m, taus)
x |
Argument of the function. |
j |
Index of basis function of order |
l |
Order of function. |
p |
The order of the splines. |
m |
The number of nonboundary knots. |
taus |
Vector of |
A numeric value of the adjusted spline f_{j}^{(l)}(x).
Choi, I., Li, B. & Wang, X. (2013). Nonparametric Estimation of Spatial and Space-Time Covariance Function. JABES 18, 611-630. https://doi.org/10.1007/s13253-013-0152-z
## Not run:
taus <- get_taus(3, 2)
adjusted_spline(1, 2, 1, 3, 2, taus)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.