| mse | R Documentation |
This function computes the mean-square difference/error between two autocovariance functions (estimated or theoretical).
mse(est1, est2)
## S3 method for class 'CovEsts'
mse(est1, est2)
## Default S3 method:
mse(est1, est2)
est1 |
A numeric vector representing the first estimated autocovariance function. |
est2 |
A numeric vector of the same length as |
This function computes the mean-square difference/error (MSE) between two estimated autocovariance functions (estimated or theoretical). The MSE is defined as
\frac{1}{n} \sum_{i=0}^{n} \left(\widehat{C}_{1}(h_{i}) - \widehat{C}_{2}(h_{i})\right)^{2}
over a set of lags \{h_{0}, h_{1} , h_{2} , \dots , h_{n} \}.
A numeric value representing the MSE between two autocovariance functions (estimated or theoretical).
mse(CovEsts): Method for CovEsts object.
mse(default): Method for numeric vectors.
x <- seq(0, 5, by=0.1)
estCov1 <- exp(-x^2)
estCov2 <- exp(-x^2.1)
mse(estCov1, estCov2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.