| print.BootEsts | R Documentation |
This function plots a BootEsts object, printing estimtor type, bootstrap type, estimator used, the bootstrap average estimate, the original estimate, and the pointwise confidence interval.
## S3 method for class 'BootEsts'
print(x, n_head = 5, n_tail = 5, digits = NULL, ...)
x |
A BootEsts S3 object. |
n_head |
The number of 'head' values to print, defaults to 5. |
n_tail |
The number of 'tail' values to print, defaults to 5. |
digits |
The number of digits to print. Defaults to |
... |
Addition printing parameters, see base::print. |
Prints a BootEsts object.
print(block_bootstrap(c(1, 2, 3), 2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.