| to_pacf | R Documentation |
This function computes the partial autocorrelation function from an estimated autocovariance or autocorrelation function.
to_pacf(estCov)
## S3 method for class 'CovEsts'
to_pacf(estCov)
## Default S3 method:
to_pacf(estCov)
estCov |
A numeric vector representing an estimated autocovariance or autocorrelation function. |
This function is a translation of the 'uni_pacf' function in src/library/stats/src/pacf.c of the R source code which is an implementation of the Durbin-Levinson algorithm.
A vector whose values are an estimate partial autocorrelation function or a CovEsts S3 object (list) with the following values
acfA numeric vector containing the partial autocorrelation estimates.
lagsA numeric vector containing the lag indices used to compute the estimates on.
est_typeThe type of estimate, namely 'partial'.
est_usedThe estimator function used, in this case, 'to_pacf'.
If a numeric vector is given for the argument estCov, then a numeric vector output is given, and if a CovEsts S3 object is given, a CovEsts object is given as output.
to_pacf(CovEsts): Method for CovEsts objects.
to_pacf(default): Method for numeric vectors.
X <- c(1, 2, 3)
to_pacf(standard_est(X, pd = FALSE, maxLag = 2, meanX = mean(X)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.