| to_vario | R Documentation |
This function computes an estimated semivariogram using an estimated autocovariance function.
to_vario(estCov)
## Default S3 method:
to_vario(estCov)
## S3 method for class 'CovEsts'
to_vario(estCov)
estCov |
A vector whose values are an estimate autocovariance function or a |
The semivariogram, \gamma(h) and autocovariance function, C(h), under the assumption of weak stationarity are related as follows:
\gamma(h) = C(0) - C(h) .
When an empirical autocovariance function is considered instead, this relation does not necessarily hold, however, it can be used to obtain a function that is close to a semivariogram, see Bilchouris and Olenko (2025).
A numeric vector whose values are an estimate of the semivariogram or an VarioEsts S3 object (list) with the following values
varioA numeric vector whose values are an estimate of the semivariogram.
lagsA numeric vector containing the lag indices used to compute the estimates on, inherited from the argument estCov.
est_usedThe estimator function used, in this case, 'to_vario'.
If a numeric vector is given for the argument estCov, then a numeric vector output is given, and if a CovEsts S3 object is given, a VarioEsts object is given as output.
to_vario(default): Method for numeric vectors.
to_vario(CovEsts): Method for CovEsts objects.
Bilchouris, A. & Olenko, A (2025). On Nonparametric Estimation of Covariogram. Austrian Statistical Society 54(1), 112-137. 10.17713/ajs.v54i1.1975
X <- c(1, 2, 3)
estCov <- standard_est(X, meanX=mean(X), maxLag = 2, pd=FALSE)
to_vario(estCov)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.